@@ -134,10 +134,10 @@ pref("gfx.color_management.display_profile", "");
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
-//@line 151 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 151 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 // Only on mac tabfocus is expected to handle UI widgets as well as web content
 pref("accessibility.tabfocus_applies_to_xul", true);
-//@line 154 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 154 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -517,9 +517,9 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 534 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 534 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.help", false);
-//@line 536 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 536 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -635,6 +635,7 @@ pref("network.IDN_show_punycode", false);
 
 // ccTLDs
 pref("network.IDN.whitelist.ac", true);
+pref("network.IDN.whitelist.ar", true);
 pref("network.IDN.whitelist.at", true);
 pref("network.IDN.whitelist.br", true);
 pref("network.IDN.whitelist.ch", true);
@@ -748,7 +749,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 770 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 771 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -772,9 +773,9 @@ pref("network.hosts.nntp_server",           "news.mozilla.org");
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 800 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 801 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  0);
-//@line 802 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 803 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1108,9 +1109,9 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1519 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 1520 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1521 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 1522 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 // Mac specific preference defaults
 pref("browser.drag_out_of_frame_style", 1);
 pref("ui.key.saveLink.shift", false); // true = shift, false = meta
@@ -1524,21 +1525,21 @@ pref("print.print_extra_margin", 90); // twips (90 twips is an eigth of an inch)
 // This indicates whether it should use the native dialog or the XP Dialog
 pref("print.use_native_print_dialog", true);
 
-//@line 1936 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 1937 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2133 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2134 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2224 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2225 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2489 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2490 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2557 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2558 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2583 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2584 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2603 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2604 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2611 "/builds/tinderbox/XR-Trunk/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
+//@line 2612 "/builds/tinderbox/Xr-Mozilla1.9-Release/Darwin_8.8.4_Depend/mozilla/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
